itemCount property
itemCount: The total number of indicators to be displayed. This should match the total number of pages or elements.
Implementation
final int itemCount;
itemCount: The total number of indicators to be displayed. This should match the total number of pages or elements.final int itemCount;