selectedItem property

int selectedItem
final
  • selectedItem: The index of the currently active or selected item. This is zero-based, meaning the first item is represented by 0.

Implementation

final int selectedItem;