onSkip property
dynamic Function()?
onSkip
final
onSkip: Callback function that is called when the skip button is pressed.
Implementation
final Function()? onSkip;
onSkip: Callback function that is called when the skip button is pressed.final Function()? onSkip;