onboarding/widgets/indicator library
Classes
- Indicator
- A custom widget that displays a horizontal list of indicators to denote the current position within a series of pages or elements. Typically used in onboarding screens or carousels.
Typedefs
- IndicatorBuilder = Widget Function(BuildContext context, int selectedItem, int itemsCount)
- Defines a function type for building Indicator widget.